@@ -75,8 +75,8 @@ panel_applet_frame_load_from_gconf (PanelWidget *panel_widget,
 	char        *temp_key;
 	char        *applet_iid;
 
-	g_return_if_fail (panel_widget);
-	g_return_if_fail (gconf_key);
+	g_return_if_fail (panel_widget != NULL);
+	g_return_if_fail (gconf_key != NULL);
 
 	client  = panel_gconf_get_client ();
 
@@ -95,7 +95,9 @@ popup_handle_remove (BonoboUIComponent *uic,
 		     PanelAppletFrame  *frame,
 		     const gchar       *verbname)
 {
-	panel_applet_clean (frame->priv->applet_info);
+	AppletInfo *info = frame->priv->applet_info;
+	frame->priv->applet_info = NULL;
+	panel_applet_clean (info);
 }
 
 static void
@@ -106,7 +108,7 @@ popup_handle_move (BonoboUIComponent *uic,
 	PanelWidget *panel;
 	GtkWidget   *widget;
 
-	g_return_if_fail (frame && GTK_IS_WIDGET (frame));
+	g_return_if_fail (GTK_IS_WIDGET (frame));
 
 	widget = GTK_WIDGET (frame);
 
@@ -144,8 +146,8 @@ panel_applet_frame_load (const gchar *iid,
 	AppletInfo *info;
 	char       *real_key;
 
-	g_return_if_fail (iid);
-	g_return_if_fail (panel);
+	g_return_if_fail (iid != NULL);
+	g_return_if_fail (panel != NULL);
 
 	if (gconf_key)
 		real_key = g_strdup (gconf_key);
@@ -172,8 +174,8 @@ panel_applet_frame_load (const gchar *iid,
 	gtk_widget_show_all (frame);
 
 	info = panel_applet_register (frame, 
-				      frame,     /* FIXME: ref? */
-				      NULL,      /* FIXME: data_destroy */
+				      NULL /* data */,
+				      NULL /* data_destroy */,
 				      panel,
 				      pos,
 				      FALSE,
@@ -302,6 +304,7 @@ panel_applet_frame_finalize (GObject *object)
 	PanelAppletFrame *frame = PANEL_APPLET_FRAME (object);
 
 	g_free (frame->priv->iid);
+	frame->priv->iid = NULL;
 
         g_free (frame->priv);
         frame->priv = NULL;
@@ -446,7 +449,7 @@ panel_applet_frame_new (const char *iid,
 {
 	PanelAppletFrame *frame;
 
-	g_return_val_if_fail (iid && gconf_key, NULL);
+	g_return_val_if_fail (iid != NULL && gconf_key != NULL, NULL);
 
 	frame = g_object_new (PANEL_TYPE_APPLET_FRAME, NULL);
 
