@@ -782,16 +782,14 @@ panel_do_popup_menu (PanelWidget *panel, BasePWidget *basep, GtkWidget *widget,
 }
 
 static gboolean
-panel_popup_menu (GtkWidget *widget)
+panel_popup_menu (GtkWidget *widget, gpointer data)
 {
  	PanelWidget *panel = NULL;
 	BasePWidget *basep = NULL;
 
-	if (BASEP_IS_WIDGET (widget)) {
-		basep = BASEP_WIDGET (widget);
-		panel = PANEL_WIDGET (basep->panel);
-	} else if (FOOBAR_IS_WIDGET (widget)) {
-		panel = PANEL_WIDGET (FOOBAR_WIDGET (widget)->panel);
+	panel = PANEL_WIDGET (widget);
+	if (BASEP_IS_WIDGET (data)) {
+		basep = BASEP_WIDGET (data);
 	}
 	return panel_do_popup_menu (panel, basep, widget, 3, GDK_CURRENT_TIME);
 }
@@ -1285,7 +1283,7 @@ get_target_list (void)
 		{ "x-url/ftp",                           0, TARGET_NETSCAPE_URL },
 		{ "_NETSCAPE_URL",                       0, TARGET_NETSCAPE_URL },
 		{ "application/x-panel-directory",       0, TARGET_DIRECTORY },
-		{ "application/x-panel-applet",          0, TARGET_APPLET },
+		{ "application/x-panel-applet-iid",      0, TARGET_APPLET },
 		{ "application/x-panel-applet-internal", 0, TARGET_APPLET_INTERNAL },
 		{ "application/x-panel-icon-internal",   0, TARGET_ICON_INTERNAL },
 		{ "application/x-color",                 0, TARGET_COLOR },
@@ -1529,9 +1527,8 @@ drag_data_recieved_cb (GtkWidget	*widget,
 			gtk_drag_finish (context, FALSE, FALSE, time);
 			return;
 		}
-		/*
-		 * FIXME: sort out applet's drag and drop
-		 */
+		panel_applet_frame_load ((char *)selection_data->data,
+					 panel, pos, NULL);
 		break;
 	case TARGET_APPLET_INTERNAL:
 		drop_internal_applet (panel, pos, (char *)selection_data->data,
@@ -1740,8 +1737,8 @@ panel_setup(GtkWidget *panelw)
 
 	g_signal_connect (G_OBJECT (panelw), "event",
 			  G_CALLBACK (panel_event), pd);
-	g_signal_connect (G_OBJECT (panelw), "popup_menu",
-                          G_CALLBACK (panel_popup_menu), pd);
+	g_signal_connect (G_OBJECT (panel), "popup_menu",
+                          G_CALLBACK (panel_popup_menu), panelw);
 	g_signal_connect (G_OBJECT (panel), "event",
 			  G_CALLBACK (panel_widget_event), panelw);
 	
